/*------------------------------------------------------------------------------
  Purpose:     Sending emails using outlook
  Author:      David Pipes   24-JUL-2007
  
  Parameters:  iEmailTo          = TO string ";" Delimits
               iEmailCC          = CC string ";" Delimits
               iEmailBCC         = BCC string ";" Delimits
               iEmailSubject     = Subject string
               iEmailBody        = Body string 
               iImportance       = Priority string 0-2 string
               iReadReceipt      = Read Receipt Logical
               iDeliveryReceipt  = Delivery Receipt Logical
               iAttachMent       = Attachments sting ";" Delimits if none then ""
               iSafeMode         = Safe Mode Logical 'Redemption' if no redemption
                                   is installed then set to true and comment out the
                                   Redemption part
                      
  Notes:       This procedure is used for sending out emails. If you are annoyed
               about the outlook dialog coming up everytime it sends and email, 
               then i would recomend installing redemption.dll. Once that is 
               installed then you can set safemode to false when calling this
               procedure. And Uncomment out the redemption code at the bottom
               and the dialog will no longer come up. Notice that redemption is
               not free. Also almost everything is ";" delimited for doing mult
               attachments, recipents.
------------------------------------------------------------------------------*/

DEFINE INPUT PARAMETER iEmailTo         AS CHARACTER   NO-UNDO. /* TO string ";" Delimits */
DEFINE INPUT PARAMETER iEmailCC         AS CHARACTER   NO-UNDO. /* CC string ";" Delimits */
DEFINE INPUT PARAMETER iEmailBCC        AS CHARACTER   NO-UNDO. /* BCC string ";" Delimits */
DEFINE INPUT PARAMETER iEmailSubject    AS CHARACTER   NO-UNDO. /* Subject string */
DEFINE INPUT PARAMETER iEmailBody       AS CHARACTER   NO-UNDO. /* Body string */
DEFINE INPUT PARAMETER iImportance      AS CHARACTER   NO-UNDO. /* Priority string 0-2 */
DEFINE INPUT PARAMETER iReadReceipt     AS LOGICAL     NO-UNDO. /* Read Receipt Logical */
DEFINE INPUT PARAMETER iDeliveryReceipt AS LOGICAL     NO-UNDO. /* Delivery Receipt Logical */
DEFINE INPUT PARAMETER iAttachMent      AS CHARACTER   NO-UNDO. /* Attachments sting ";" Delimits */
DEFINE INPUT PARAMETER iSafeMode        AS LOGICAL     NO-UNDO. /* Safe Mode Logical 'Redemption'*/

DEFINE VARIABLE hFolder    AS COM-HANDLE   NO-UNDO.
DEFINE VARIABLE hMailItem  AS COM-HANDLE   NO-UNDO.
DEFINE VARIABLE hNameSpace AS COM-HANDLE   NO-UNDO.
DEFINE VARIABLE hOutlook   AS COM-HANDLE   NO-UNDO.
DEFINE VARIABLE hSafeItem  AS COM-HANDLE   NO-UNDO.
DEFINE VARIABLE hUserLogin AS COM-HANDLE   NO-UNDO.
DEFINE VARIABLE wasError   AS LOGICAL      NO-UNDO.
DEFINE VARIABLE X          AS INTEGER      NO-UNDO.

ASSIGN
    iReadReceipt     = FALSE
    iDeliveryReceipt = FALSE
    wasError         = FALSE.

/* Creates connection to the outlook object model */
CREATE "Outlook.Application" hOutlook CONNECT NO-ERROR.
IF ERROR-STATUS:ERROR THEN
DO:
    CREATE "Outlook.Application" hOutlook NO-ERROR.
    IF ERROR-STATUS:ERROR THEN
        RETURN ERROR.

    wasError = TRUE.
END.

/* Setting com-handles to Mapi and the INbox folder */
ASSIGN
    hNameSpace = hOutlook:GetNameSpace("MAPI":U).
    hFolder    = hNameSpace:GetDefaultFolder(6) NO-ERROR. /* 6 = Inbox */
IF ERROR-STATUS:NUM-MESSAGES <> 0 THEN
DO:
    MESSAGE "There was a problem locating your inbox folder." SKIP
            "Please contact MIS"
            VIEW-AS ALERT-BOX ERROR BUTTONS OK
            TITLE "Issues Assigning Com-Handles".
    
    wasError = TRUE.
END.

/* Assigning the email parameters */
ASSIGN
    hMailItem                                   = hFolder:Items:Add()
    hMailItem:TO                                = iEmailTo
    hMailItem:Subject                           = iEmailSubject
    hMailItem:CC                                = iEmailCC
    hMailItem:BCC                               = iEmailBCC
    hMailItem:Body                              = iEmailBody
    hMailItem:Importance                        = iImportance
    hMailItem:OriginatorDeliveryReportRequested = iDeliveryReceipt
    hMailItem:ReadReceiptRequested              = iReadReceipt NO-ERROR.

IF ERROR-STATUS:NUM-MESSAGES <> 0 THEN
DO:
    MESSAGE "There was a problem setting your email Parameters." SKIP
            "Please contact MIS"
            VIEW-AS ALERT-BOX ERROR BUTTONS OK
            TITLE "Email Parameter Issues".
    wasError = TRUE.
END.

/* This attaches each attachment in a ";" delimited STRING where   */
/* the fill path to the attachment is it. Multiples are delimited  */
/* Also this will work with just one file path..                   */
IF iAttachMent <> "" THEN
    DO:
        REPEAT X = 1 TO NUM-ENTRIES(iAttachment, ";"):
            hMailItem:Attachments:Add(TRIM(ENTRY(X, iAttachment, ";"))).
        END.

        IF ERROR-STATUS:NUM-MESSAGES <> 0 THEN
        DO:
            MESSAGE "There was a problem Finding your attachment." SKIP
                    "Please contact MIS" SKIP(1)
                    iAttachment
                    VIEW-AS ALERT-BOX ERROR BUTTONS OK
                    TITLE "Problems attaching your files".
            wasError = TRUE.
        END.
    END.

/* This will Do default Outlook Security */
IF iSafeMode = TRUE THEN
    DO:

        hMailItem:Save.
        hMailItem:send() NO-ERROR.
        IF ERROR-STATUS:NUM-MESSAGES <> 0 THEN
        DO:
            MESSAGE "There was a problem with sending your email" SKIP
                    "Please Contact MIS"
                    VIEW-AS ALERT-BOX ERROR BUTTONS OK
                    TITLE "Error Sending".
            wasError = TRUE.
        END.
    END.
/* ELSE                                                                            */
/*     DO:                                                                         */
/*         /* Redemption Security Bypass */                                        */
/*         CREATE "Redemption.SafeMailItem" hSafeItem NO-ERROR.                    */
/*         IF ERROR-STATUS:NUM-MESSAGES <> 0 THEN                                  */
/*         DO:                                                                     */
/*             MESSAGE "You are encountering and error based on 'Redemption'" SKIP */
/*                     "Please contact MIS"                                        */
/*                 VIEW-AS ALERT-BOX ERROR BUTTONS OK                              */
/*                 TITLE "Redemption Error".                                       */
/*                                                                                 */
/*             wasError = TRUE.                                                    */
/*         END.                                                                    */
/*                                                                                 */
/*                                                                                 */
/*         hSafeItem:ITEM = hMailItem. /* points redemption to mailitem */         */
/*                                                                                 */
/*         hSafeItem:save.                                                         */
/*         hSafeItem:Send() NO-ERROR.                                              */
/*         IF ERROR-STATUS:NUM-MESSAGES <> 0 THEN                                  */
/*         DO:                                                                     */
/*             MESSAGE "There was a problem sending your email" SKIP               */
/*                     "Please Contact MIS"                                        */
/*                     VIEW-AS ALERT-BOX ERROR BUTTONS OK                          */
/*                     TITLE "Error Sending with Redemption".                      */
/*                                                                                 */
/*             wasError = TRUE.                                                    */
/*         END.                                                                    */
/*     END.                                                                        */

    IF wasError = TRUE THEN
        MESSAGE "There may have been problems sending your email"
            VIEW-AS ALERT-BOX INFO BUTTONS OK.
        

/* Release Com-handles */
RELEASE OBJECT hFolder    NO-ERROR.
RELEASE OBJECT hMailItem  NO-ERROR.
RELEASE OBJECT hNameSpace NO-ERROR.
RELEASE OBJECT hOutlook   NO-ERROR.
RELEASE OBJECT hSafeItem  NO-ERROR.

